View source: R/direct_from_observed_intervals.R
| direct_from_observed_intervals | R Documentation |
Given observed transition intervals, determine the "worst" (least informative) possible direct transition intervals that could have occurred to form this sample.
direct_from_observed_intervals(observed_intervals, tmat, gd)
observed_intervals |
Output from |
tmat |
A transition matrix as created by |
gd |
A
The true transition time between states is then interval censored between the times. |
A data.frame with the following named columns
entry_time:Time of entry into "from" state;
time_from:Last time subject(id) was seen in state "from";
time_to:First time subject(id) was seen in state "to";
from:State from which a transition was observed;
to:State to which the transition was observed;
id:Subject identifier;
For right-censored observations, entry_time denotes the first time
seen in the censored state, time_from the last time seen in the censored state,
time_to is Inf, from the censored state and to is NA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.