Given censoring/truncation intervals, find the maxcliques and determine the support of the interval censored problem.
supportHudgens(intervals, reduction = TRUE, existence = FALSE)graph: An igraph object representing the censoring/truncation intervals
support: Support estimated from the censoring intervals
dir_graph: A directed igraph object used to determine whether the NPMLE
exists in the presence of left-truncation.
exist_mle: Logical output indicating whether the NPMLE exists.
A data.frame with 3 columns containing half-open intervals (left open, right closed) and an indicator whether the interval results from a censored transition or truncation:
L:Left side of interval;
R:Right side of interval;
cens:Indicator whether interval resulted from interval censoring or left truncation (1 = censoring, 0 = truncation);
id:(optional) Identifier for the observation this interval belongs to (numeric/integer). Only required if existence = TRUE;
Note that the truncation intervals need to be in the form (N, Inf] with N a numeric value.
Should the support be reduced using Lemma 3 from Hudgens (2005)? This requires checking an extra condition. Default is TRUE.
Should the existence of the NPMLE be checked using Theorem 1/Lemma 4 from
Hudgens (2005)? Requires id to be present in intervals. Default is FALSE.
Michael G. Hudgens, On Nonparametric Maximum Likelihood Estimation with Interval Censoring and Left Truncation, Journal of the Royal Statistical Society Series B: Statistical Methodology, Volume 67, Issue 4, September 2005, Pages 573-587, tools:::Rd_expr_doi("10.1111/j.1467-9868.2005.00516.x")